@@ -83,13 +83,13 @@ void KOEventPopupMenu::appendEventOnlyItems()
 
     mEventOnlyItems.append(
         addAction(QIcon::fromTheme(QStringLiteral("task-new")), i18nc("@action:inmenu", "Create To-do from Event"), this, &KOEventPopupMenu::createTodo));
-    mEventOnlyItems.last()->setObjectName(QStringLiteral("createtodo")); // id used by unit test
+    mEventOnlyItems.last()->setObjectName(QLatin1StringView("createtodo")); // id used by unit test
 
     mEventOnlyItems.append(addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
                                      i18nc("@action:inmenu", "Create Note for Event"),
                                      this,
                                      qOverload<>(&KOEventPopupMenu::createNote)));
-    mEventOnlyItems.last()->setObjectName(QStringLiteral("createnoteforevent")); // id used by unit test
+    mEventOnlyItems.last()->setObjectName(QLatin1StringView("createnoteforevent")); // id used by unit test
 }
 
 void KOEventPopupMenu::appendTodoOnlyItems()
@@ -105,13 +105,13 @@ void KOEventPopupMenu::appendTodoOnlyItems()
                                     i18nc("@action:inmenu", "Create Event from To-do"),
                                     this,
                                     qOverload<>(&KOEventPopupMenu::createEvent)));
-    mTodoOnlyItems.last()->setObjectName(QStringLiteral("createevent")); // id used by unit test
+    mTodoOnlyItems.last()->setObjectName(QLatin1StringView("createevent")); // id used by unit test
 
     mTodoOnlyItems.append(addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
                                     i18nc("@action:inmenu", "Create Note for To-do"),
                                     this,
                                     qOverload<>(&KOEventPopupMenu::createNote)));
-    mTodoOnlyItems.last()->setObjectName(QStringLiteral("createnotefortodo")); // id used by unit test
+    mTodoOnlyItems.last()->setObjectName(QLatin1StringView("createnotefortodo")); // id used by unit test
 }
 
 void KOEventPopupMenu::appendReminderOnlyItems()
@@ -342,7 +342,7 @@ void KOEventPopupMenu::createEvent()
 
         IncidenceEditorNG::IncidenceDialog *dlg =
             IncidenceEditorNG::IncidenceDialogFactory::create(true, KCalendarCore::IncidenceBase::TypeEvent, nullptr, this);
-        dlg->setObjectName(QStringLiteral("incidencedialog"));
+        dlg->setObjectName(QLatin1StringView("incidencedialog"));
         dlg->load(newEventItem);
         dlg->open();
     }
@@ -415,7 +415,7 @@ void KOEventPopupMenu::createTodo()
 
         IncidenceEditorNG::IncidenceDialog *dlg =
             IncidenceEditorNG::IncidenceDialogFactory::create(true, KCalendarCore::IncidenceBase::TypeTodo, nullptr, this);
-        dlg->setObjectName(QStringLiteral("incidencedialog"));
+        dlg->setObjectName(QLatin1StringView("incidencedialog"));
         dlg->load(newTodoItem);
         dlg->open();
     }
